@@ -1 +1,6 @@
 from ftransc.core.queue.consumer import worker
+
+
+__all__ = [
+    'worker',
+]
