@@ -1 +1,5 @@
 from ftransc.metadata.metadata import Metadata
+
+__all__ = [
+    'Metadata',
+]
